<?php 
/* Plugin Name: SheepTools Integration
 * Plugin URI: 
 * Description: Wordpress integration with SheepTools services
 * Version: 1.0 
 * Author: Etienne Richards
 * Author URI: https://info.sheeptools.com 
 * License: GPLv2 
 */

// Hook to add custom links to the plugin row
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'sheeptools_custom_plugin_links');

// Function to add custom links
function sheeptools_custom_plugin_links($links) {
    // Add your custom links
    $custom_links = array(
        '<a href="https://info.sheeptools.com/wordpress/" target="_blank">Instructions</a>',
        '<a href="https://sheeptools.com" target="_blank">SheepTools</a>',
    );

    // Merge the custom links with the existing links
    return array_merge($custom_links, $links);
}

add_action( 'wp_head', 'sheeptools_header' );

function sheeptools_header() { ?>
<!-- SheepTools Header Start -->
<!-- SheepTools Header End -->
<?php 
}

function sheeptoolsIsValidId($id) {
    if (strlen($id) === 16) {
        // Check if the first 10 characters are digits
        if (ctype_digit(substr($id, 0, 10))) {
            // Check if all characters are alphanumeric
            if (ctype_alnum($id)) {
                return true;
            }
        }
    }

    return false;
}

add_shortcode( 'st_hierarchy', 'sheeptools_hierarchy' );

function sheeptools_hierarchy( $atts ) {
    extract( shortcode_atts( array(
        'test' => 'false',
        'id' => '',
        'width' => '660px',
        'height' => '350px',
        'expand' => '0',
        'level' => '1',
        'ebvs' => 'wwt,pwwt,mwwt,nlb,nlw'
    ), $atts ) );

    $test = sanitize_text_field( trim($test) );
    $id = sanitize_text_field( trim($id) );
    $width = sanitize_text_field( trim($width) );
    $height = sanitize_text_field( trim($height) );
    $expand = sanitize_text_field( trim($expand) );
    $level = sanitize_text_field( trim($level) );
    $ebvs = sanitize_text_field( trim($ebvs) );

    $width = ctype_digit($width) ? $width . "px" : $width;
    $height = ctype_digit($height) ? $height . "px" : $height;
    
    $serverName = ("true" === $test) ? "//localhost:8080/NSIPWebApplication" : "//sheeptools.com";
    
    if(sheeptoolsIsValidId($id)) { ?>        
<!-- SheepTools Hierarchy Short Code Start -->
    <iframe src="<?php print($serverName)?>/widget/pedigree?expand=<?php print($expand)?>&level=<?php print($level)?>&id=<?php print($id)?>&ebvs=<?php print($ebvs)?>" 
        width="<?php print($width)?>" height="<?php print($height)?>" frameborder="0"
        style="background-color: transparent; border: none;" ></iframe>

<!-- SheepTools Hierarchy Short Code End -->
<?php 
    }
}

add_shortcode( 'st_radar', 'sheeptools_radar' );

function sheeptools_radar( $atts ) {
    extract( shortcode_atts( array(
        'test' => 'false',
        'id' => '',
        'accuracy' => 'true',
        'width' => '660px',
        'height' => '350px',
        'ebvs' => 'wwt,pwwt,mwwt,nlb,nlw'
    ), $atts ) );

    $test = sanitize_text_field( trim($test) );
    $id = sanitize_text_field( trim($id) );
    $accuracy = sanitize_text_field( trim($accuracy) );
    $width = sanitize_text_field( trim($width) );
    $height = sanitize_text_field( trim($height) );
    $ebvs = sanitize_text_field( trim($ebvs) );

    $width = ctype_digit($width) ? $width . "px" : $width;
    $height = ctype_digit($height) ? $height . "px" : $height;
    $serverName = ("true" === $test) ? "//localhost:8080/NSIPWebApplication" : "//sheeptools.com";
    
    if(sheeptoolsIsValidId($id)) { ?>        
<!-- SheepTools Hierarchy Short Code Start -->
    <iframe src="<?php print($serverName)?>/widget/radar?id=<?php print($id)?>&accuracy=<?php print($accuracy)?>&ebvs=<?php print($ebvs)?>" 
        width="<?php print($width)?>" height="<?php print($height)?>" frameborder="0" scrolling="no"
        style="background-color: transparent; border: none;" ></iframe>

<!-- SheepTools Hierarchy Short Code End -->
<?php 
    }
}
